<?php include('header.php'); ?>

<?php
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // declare an empty array to contain any posted errors
    $errors = [];

    // field validation & notification
    if (empty($_POST['name'])) $errors[] = "Full Name is required.";
    if (empty($_POST['email']) || !filter_var($_POST['email'], FILTER_VALIDATE_EMAIL)) $errors[] = "Valid Email is required.";
    if (empty($_POST['gamertag'])) $errors[] = "Gamertag is required.";
    if (empty($_POST['gender'])) $errors[] = "Gender selection is required.";
    if (empty($_POST['comments'])) $errors[] = "Comment box cannot be empty.";

    // validation for the user's date of birth
    $month_names = [
        "January" => 1, "February" => 2, "March" => 3, "April" => 4, "May" => 5, "June" => 6,
        "July" => 7, "August" => 8, "September" => 9, "October" => 10, "November" => 11, "December" => 12
    ];

    $month_text = $_POST['month'];
    $day = isset($_POST['day']) ? intval($_POST['day']) : 0;
    $year = isset($_POST['year']) ? intval($_POST['year']) : 0;

    if ($month_text == "Select Month" || empty($day) || empty($year)) {
        $errors[] = "Please select a valid date of birth.";
    } elseif (!isset($month_names[$month_text]) || !checkdate($month_names[$month_text], $day, $year)) {
        $errors[] = "Invalid date selected.";
    }

    // validation for checkboxes, whereas one must be selected
    if (!isset($_POST['interests']) || !is_array($_POST['interests']) || count($_POST['interests']) == 0) {
        $errors[] = "Please select at least one interest.";
    }

    if (empty($errors)) {
        // if we have no errors, then we will then echo
        // the information to the user.
        echo "<h2>Thank You for Registering!</h2>";
        echo "<p><strong>Full Name:</strong> " . htmlspecialchars($_POST['name']) . "</p>";
        echo "<p><strong>Email:</strong> " . htmlspecialchars($_POST['email']) . "</p>";
        echo "<p><strong>Gamertag:</strong> " . htmlspecialchars($_POST['gamertag']) . "</p>";
        echo "<p><strong>Date of Birth:</strong> " . htmlspecialchars($month_text) . " " . htmlspecialchars($day) . ", " . htmlspecialchars($year) . "</p>";
        echo "<p><strong>Gender:</strong> " . htmlspecialchars($_POST['gender']) . "</p>";
        echo "<p><strong>Interests:</strong> " . implode(", ", array_map('htmlspecialchars', $_POST['interests'])) . "</p>";
        echo "<p><strong>Comments:</strong> " . nl2br(htmlspecialchars($_POST['comments'])) . "</p>";
    } else {
        // an error has been trapped, we will display these
        // to the user
        echo "<h2>Form Submission Failed</h2>";
        echo "<p>Please correct the following errors:</p>";
        echo "<ul>";
        foreach ($errors as $error) {
            // iterate and echo each error to the window in an unordered list
            echo "<li>$error</li>";
        }
        echo "</ul>";
        echo "<a href='index.php'>Go Back</a>";
    }
}
?>

<?php include('footer.php'); ?>
